@@ -49,6 +49,7 @@ sub build_having_col {
             [ @pre, @{$sql->{cols}} ],
             { %{$sf->{i}{lyt_h}}, info => $info }
         );
+        $ax->print_sql_info( $info );
         if ( ! defined $quote_col ) {
             return;
         }
@@ -97,6 +98,7 @@ sub choose_and_add_operator {
                 [ @pre, @operators_default ],
                 { %{$sf->{i}{lyt_h}}, info => $info }
             );
+            $ax->print_sql_info( $info );
             if ( ! defined $op ) {
                 return;
             }
@@ -113,6 +115,7 @@ sub choose_and_add_operator {
                     [ @pre, @operators_limited ],
                     { %{$sf->{i}{lyt_h}}, info => $info, prompt => 'First select the operator:' }
                 );
+                $ax->print_sql_info( $info );
                 if ( ! defined $op ) {
                     next OPERATOR;
                 }
@@ -141,20 +144,22 @@ sub __add_operator {
     my $stmt = $clause . '_stmt';
     my $args = $clause . '_args';
     my $ok;
+    $ax->print_sql_info( $ax->get_sql_info( $sql ) );
     if ( $op =~ /^(.+)\s(%?col%?)\z/ ) {
         $op = $1;
         my $arg = $2;
         $sql->{$stmt} .= ' ' . $op;
-        my $info = $ax->get_sql_info( $sql );
         my $quote_col;
         if ( $stmt eq 'having_stmt' ) {
             my @pre = ( undef, $sf->{i}{ok} );
             my @choices = ( @{$sf->{aggregate}}, map( '@' . $_,  @{$sql->{aggr_cols}} ) );
+            my $info = $ax->get_sql_info( $sql );
             # Choose
             my $aggr = $tc->choose(
                 [ @pre, @choices ],
                 { %{$sf->{i}{lyt_h}}, info => $info }
             );
+            $ax->print_sql_info( $info );
             if ( ! defined $aggr ) {
                 return;
             }
@@ -165,11 +170,13 @@ sub __add_operator {
             $sql->{$stmt} = $backup_tmp;
         }
         else {
+            my $info = $ax->get_sql_info( $sql );
             # Choose
             $quote_col = $tc->choose(
                 $sql->{cols},
                 { %{$sf->{i}{lyt_h}}, info => $info, prompt => 'Col:' }
             );
+            $ax->print_sql_info( $info );
         }
         if ( ! defined $quote_col ) {
             return;
@@ -192,7 +199,6 @@ sub __add_operator {
         }
     }
     elsif ( $op =~ /REGEXP(_i)?\z/ ) {
-        $ax->print_sql_info( $sql );
         $sql->{$stmt} =~ s/ (?: (?<=\() | \s ) \Q$quote_col\E \z //x;
         my $do_not_match_regexp = $op =~ /^NOT/       ? 1 : 0;
         my $case_sensitive      = $op =~ /REGEXP_i\z/ ? 0 : 1;
@@ -211,7 +217,7 @@ sub __add_operator {
     else {
         $sql->{$stmt} .= ' ' . $op;
     }
-    $ax->print_sql_info( $sql );
+    $ax->print_sql_info( $ax->get_sql_info( $sql ) );
     return 1;
 }
 
@@ -260,6 +266,7 @@ sub read_and_add_value {
                     'Value: ',
                     { info => $info }
                 );
+                $ax->print_sql_info( $info );
                 if ( ! defined $value ) {
                     return;
                 }
@@ -276,23 +283,25 @@ sub read_and_add_value {
             }
         }
         elsif ( $op =~ /^(?:NOT\s)?BETWEEN\z/ ) {
-            my $info_1 = $ax->get_sql_info( $sql );
+            my $info = $ax->get_sql_info( $sql );
             # Readline
             my $value_1 = $tf->readline(
                 'Value 1: ',
-                { info => $info_1 }
+                { info => $info }
             );
+            $ax->print_sql_info( $info );
             if ( ! defined $value_1 ) {
                 return;
             }
             $sql->{$stmt} .= ' ' . '?' . ' AND';
             push @{$sql->{$args}}, $value_1;
-            my $info_2 = $ax->get_sql_info( $sql );
+            $info = $ax->get_sql_info( $sql );
             # Readline
             my $value_2 = $tf->readline(
                 'Value 2: ',
-                { info => $info_2 }
+                { info => $info }
             );
+            $ax->print_sql_info( $info );
             if ( ! defined $value_2 ) {
                 return;
             }
@@ -308,6 +317,7 @@ sub read_and_add_value {
                 'Pattern: ',
                 { info => $info }
             );
+            $ax->print_sql_info( $info );
             if ( ! defined $value ) {
                 return;
             }
@@ -317,13 +327,14 @@ sub read_and_add_value {
             return 1;
         }
         else {
-            my $info = $ax->get_sql_info( $sql );
             my $prompt = $op =~ /^(?:NOT\s)?LIKE\z/ ? 'Pattern: ' : 'Value: '; #
+            my $info = $ax->get_sql_info( $sql );
             # Readline
             my $value = $tf->readline(
                 $prompt,
                 { info => $info }
             );
+            $ax->print_sql_info( $info );
             if ( ! defined $value ) {
                 return;
             }
